<script setup>
/**
 * getList 获取列表
 * headList 列定义
 *          order 是否排序
 *          orderFun: function (a, b){ return Number(a.code) > Number(b.code) ? 1 : -1 }  排序函数
 *          fixed 是否固定列
 *          filters 列过滤
 *          filterFun 过滤函数
 *          slot 自定义列, row为当前列插槽传参， 接收 <template #code="scope"> </template>， code为插槽名
 * select 是否可选择
 *
 */
import {onMounted, ref} from "vue";

const props = defineProps({
    getList: {
        type: Function,
        default: () => {},
        required: true
    },
    headList: {
        type: Array,
        default: [],
        required: true
    },
    select: {
        type: Boolean,
        default: false
    }
})

const state = reactive({
    page: 1,
    limit: 10,
    total: 0,
    list: []
})
const loading = ref(false);

const getData = (data) => {
    const pagedata = { limit: state.limit, page: data.page}
    loading.value = true;
    props.getList(pagedata).then(res => {
        state.list = res.list
        state.total = res.total
    }).finally(() => {
        loading.value = false;
    })
}

onMounted(() =>{
    getData({ page: state.page })
})
</script>

<template>
    <div style="width: 100%; height: 100%">
        <el-table :data="state.list"
                  v-loading="loading"
                  ref="multipleTable"
                  style="width: 100%; height: 85%">
            <el-table-column v-if="props.select" type="selection"></el-table-column>
            <el-table-column
                type="index"
                label="序号"
                align="center"
                width="80px"
            ></el-table-column>
            <template v-for="item in props.headList">
                <!-- 排序列 -->
                <el-table-column
                    v-if="item.order"
                    :prop="item.prop"
                    :label="item.label"
                    :sortable="item?.order"
                    :sort-method="item?.orderFun"
                />
                <!-- 正常列 -->
                <el-table-column
                    v-else
                    :prop="item.prop"
                    :label="item.label"
                    :fixed="item?.fixed"
                    :filters="item?.filters"
                    :filter-method="item?.filterFun"
                >
                    <template #default="scope">
                        <!-- 自定义列 -->
                        <template v-if="item?.slot">
                            <slot :name="item.prop" :row="scope.row"></slot>
                        </template>
                    </template>
                </el-table-column>
            </template>
        </el-table>
        <div class="pagination">
            <div class="pagination-total">共{{state.total}}条</div>
            <pagination
                v-show="state.total > 0"
                layout="prev, pager, next, jumper"
                :total="state.total"
                :page="state.current"
                :limit="state.limit"
                @pagination="getData"
            />
            <!-- 页面右侧自定义插槽，可以加自定义按钮 -->
            <slot name="pagination"></slot>
        </div>
    </div>
</template>

<style scoped lang="scss">
.pagination{
    display: flex;
    align-items: center;
    justify-content: flex-end;
    .pagination-total{
        color: #fff;
    }
}
:deep(.pagination-container){
    background-color: transparent;
    margin: 0;
    padding: 20px;
}
</style>